#!/bin/sh

NAME="zerotier-one"
ZT_ONE="/usr/sbin/${NAME}"
ZT_IDTOOL="/usr/sbin/zerotier-idtool"

ZT_RO_HOME="/etc/${NAME}"

[ -e /etc/default/zerotier-one ] && . /etc/default/zerotier-one

: ${ZT_HOME:="/mnt/storage/${NAME}"}

IDENTITY_SECRET="identity.secret"
IDENTITY_PUBLIC="identity.public"
AUTH_TOKEN="authtoken.secret"
TE_FILE="zerotier-one.te"

LN_FILES="${IDENTITY_SECRET} ${IDENTITY_PUBLIC} ${AUTH_TOKEN} ${TE_FILE}"

echo -n "Checking if ${NAME} exists... "

if [ -e ${ZT_ONE} ]; then
  echo "found!"
else
  echo "not found, exiting!"
  exit 0
fi

# Check if directory exists
if [ ! -d ${ZT_RO_HOME} ]; then
  mkdir -p ${ZT_RO_HOME}
fi

echo -n "Checking Identity... "
if [[ ! -f ${ZT_RO_HOME}/${IDENTITY_SECRET} && ! -f ${ZT_RO_HOME}/${IDENTITY_PUBLIC} ]]; then
  echo "creating..."
  ${ZT_IDTOOL} generate ${ZT_RO_HOME}/${IDENTITY_SECRET} ${ZT_RO_HOME}/${IDENTITY_PUBLIC} && \
  echo "done"
else
  echo "exists"
fi

echo -n "Checking authtoken... "
if [[ ! -f ${ZT_RO_HOME}/${AUTH_TOKEN} ]]; then
  echo -n "creating..."
  head -c 1024 /dev/urandom | md5sum | head -c 24 > ${ZT_RO_HOME}/${AUTH_TOKEN} && \
  chmod 0600 ${ZT_RO_HOME}/${AUTH_TOKEN} && \
  echo "done"
else
  echo "exists"
fi

echo -n "Checking if storage mounted... "
mount | grep -qi '/mnt/storage'
if [ $? -eq 0 ]; then
  echo "found!"

  mkdir -p ${ZT_HOME}
  for file in ${LN_FILES}; do
    ln -sf ${ZT_RO_HOME}/${file} ${ZT_HOME}/${file}
  done

else
  echo "not found!"
fi
